==> plasma-framework-4.98.0.tar.xz: plasma-framework-4.98.0/src/declarativeimports/core/svgtexturenode.h <==
/***************************************************************************
 *   Copyright 2014 David Edmundson <davidedmundson@kde.org>               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef SVGTEXTURENODE_H
#define SVGTEXTURENODE_H

#include <QSGSimpleTextureNode>

namespace Plasma {

/**
* This class wraps QSGSimpleTextureNode
* and manages the lifespan on the texture
*/

class SVGTextureNode : public QSGSimpleTextureNode
{
    public:
        SVGTextureNode() {}
        /**
         * Set the current texture
         * the object takes ownership of the texture
         */
        void setTexture(QSGTexture *texture) {
            m_texture.reset(texture);
            QSGSimpleTextureNode::setTexture(texture);
        }
    private:
        QScopedPointer<QSGTexture> m_texture;
};

}
#endif // SVGTextureNode

==> plasma-framework-4.100.0.tar.xz: plasma-framework-4.100.0/src/declarativeimports/core/svgtexturenode.h <==
/***************************************************************************
 *   Copyright 2014 David Edmundson <davidedmundson@kde.org>               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef SVGTEXTURENODE_H
#define SVGTEXTURENODE_H

#include <QSGSimpleTextureNode>

namespace Plasma
{

/**
* This class wraps QSGSimpleTextureNode
* and manages the lifespan on the texture
*/

class SVGTextureNode : public QSGSimpleTextureNode
{
public:
    SVGTextureNode() {}
    /**
     * Set the current texture
     * the object takes ownership of the texture
     */
    void setTexture(QSGTexture *texture)
    {
        m_texture.reset(texture);
        QSGSimpleTextureNode::setTexture(texture);
    }
private:
    QScopedPointer<QSGTexture> m_texture;
};

}
#endif // SVGTextureNode
